@@ -5,6 +5,6 @@ from ._version import __version__
 from .henge import *
 
 __classes__ = ["Henge"]
-__all__ = __classes__ + ["connect_mongo"]
+__all__ = __classes__ + ["connect_mongo", "split_schema"]
 
 logmuse.init_logger("henge")
